@@ -54,6 +54,8 @@ Later updates (from the source web site):
 
 =item * version 0.60, published on February 6, 2006
 
+=item * version 0.68, published on April 3, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -92,4 +94,4 @@ traylor uncle_albert uncle_max uncle_ned upholsterygeist virginia
 waldo wally walter wendel wendy will willy wilson wilt_gandhi winston
 world_s_smartest_garbage_man yergi yorgi yugi yvonne zenox zimbu zoltar
 tex flashy petricia tim_zumph earl lefty sourpuss wendel_j_stone_iv
-vijay exactly_man alan
+vijay exactly_man alan andy
